@@ -323,6 +323,8 @@ class TrainedModel(Base):
     running_r_squared = Column(Float, nullable=True, default=0)  # R² (R-squared) - Running evaluation metric
     running_rmse = Column(Float, nullable=True)  # Root Mean Squared Error (RMSE)
 
+    score = Column(Float, nullable=True, default=0)  # Score for how well the model is performing.
+    score_window = Column(Integer, nullable=True, default=0)  # Number of records evaluated.
     correction_factor = Column(Float, nullable=True)  # Running Correction Factor (if applicable)
     avg_correction_error = Column(Float, nullable=True)  # Average Correction Error
     avg_last_n_corrections = Column(Float, nullable=True)  # Average of Last N Corrections
@@ -429,21 +431,19 @@ class EvaluatedModel(Base):
     model = Column(String(50), nullable=False)
     feed = Column(String(25), nullable=False)
     voting_round = Column(Integer, nullable=False)
-    prediction = Column(Float, nullable=True)  # Correction Factor. Typically, the last observed Moving Average.
+    prediction = Column(Float, nullable=True)
     target = Column(Float, nullable=True)
-    diff = Column(Float, nullable=True)
-    diff_clean = Column(Float, nullable=True)
-    diff_ema = Column(Float, nullable=True)
     original_error = Column(Float, nullable=True)
-    revision_confidence = Column(Float, nullable=True)
-    revision_confidence_ema = Column(Float, nullable=True)
+    error_direction_ema = Column(Float, nullable=True)
+    error_magnitude = Column(Float, nullable=True)
+    error_magnitude_ema = Column(Float, nullable=True)
+    direction_consistency = Column(Float, nullable=True)
+    correction_factor = Column(Float, nullable=True)
     revised_prediction = Column(Float, nullable=True)
     revised_error = Column(Float, nullable=True)
     rmse = Column(Float, nullable=True)
     r2 = Column(Float, nullable=True)
     score = Column(Float, nullable=True)
-    stability_factor = Column(Float, nullable=True)
-    revised_error_confidence = Column(Float, nullable=True)
     evaluation_count = Column(Integer, nullable=False, autoincrement=True)
     status = Column(Integer, nullable=True)
     # Timestamp with default UTC now
