@@ -32,6 +32,8 @@ class TrainedModel(Base):
     running_r_squared = Column(Float, nullable=True, default=0)  # R² (R-squared) - Running evaluation metric
     running_rmse = Column(Float, nullable=True)  # Root Mean Squared Error (RMSE)
 
+    score = Column(Float, nullable=True, default=0)  # Score for how well the model is performing.
+    score_window = Column(Integer, nullable=True, default=0)  # Number of records evaluated.
     correction_factor = Column(Float, nullable=True)  # Running Correction Factor (if applicable)
     avg_correction_error = Column(Float, nullable=True)  # Average Correction Error
     avg_last_n_corrections = Column(Float, nullable=True)  # Average of Last N Corrections
